Package: compSPOT
Type: Package
Title: compSPOT: Tool for identifying and comparing significantly
        mutated genomic hotspots
Version: 1.10.0
Authors@R: c(
    person("Sydney", "Grant", email = "Sydney.Grant@roswellpark.org", 
    role = c("aut", "cre"), 
    comment = c(ORCID = "0000-0003-1849-5921")),
    person("Ella", "Sampson", email = "ellasamp@buffalo.edu", role = c("aut")),
    person("Rhea", "Rodrigues", 
    email = "RheaCarmelGlen.Rodrigues@roswellpark.org", 
    role = c("aut"), comment = c(ORCID = "0000-0002-8573-8658")),
    person("Gyorgy", "Paragh", email = "Gyorgy.Paragh@roswellpark.org", 
    role = c("aut"), comment = c(ORCID = "0000-0002-6612-9267")))
Description: Clonal cell groups share common mutations within cancer,
        precancer, and even clinically normal appearing tissues. The
        frequency and location of these mutations may predict prognosis
        and cancer risk. It has also been well established that certain
        genomic regions have increased sensitivity to acquiring
        mutations. Mutation-sensitive genomic regions may therefore
        serve as markers for predicting cancer risk. This package
        contains multiple functions to establish significantly mutated
        hotspots, compare hotspot mutation burden between samples, and
        perform exploratory data analysis of the correlation between
        hotspot mutation burden and personal risk factors for cancer,
        such as age, gender, and history of carcinogen exposure. This
        package allows users to identify robust genomic markers to help
        establish cancer risk.
License: Artistic-2.0
Encoding: UTF-8
LazyData: FALSE
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
biocViews: Software, Technology, Sequencing, DNASeq, WholeGenome,
        Classification, SingleCell, Survival, MultipleComparison
Imports: stats, base, ggplot2, plotly, magrittr, ggpubr, gridExtra,
        utils, data.table
Suggests: BiocStyle, knitr, rmarkdown, testthat (>= 3.0.0)
VignetteBuilder: knitr
URL: https://github.com/sydney-grant/compSPOT
BugReports: https://github.com/sydney-grant/compSPOT/issues
Config/testthat/edition: 3
Depends: R (>= 4.3.0)
Config/pak/sysreqs: cmake make libicu-dev libuv1-dev libssl-dev
Repository: https://bioc-release.r-universe.dev
Date/Publication: 2026-04-28 13:01:21 UTC
RemoteUrl: https://github.com/bioc/compSPOT
RemoteRef: RELEASE_3_23
RemoteSha: 1d761dbe40e29bfcd0d01a002f033e7608696c9e
NeedsCompilation: no
Packaged: 2026-05-03 16:10:12 UTC; root
Author: Sydney Grant [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-1849-5921>),
  Ella Sampson [aut],
  Rhea Rodrigues [aut] (ORCID: <https://orcid.org/0000-0002-8573-8658>),
  Gyorgy Paragh [aut] (ORCID: <https://orcid.org/0000-0002-6612-9267>)
Maintainer: Sydney Grant <Sydney.Grant@roswellpark.org>
Built: R 4.6.0; ; 2026-05-03 16:45:20 UTC; unix
