# Generated by roxygen2: do not edit by hand

export(compare_features)
export(compare_groups)
export(find_hotspots)
importFrom(data.table,rbindlist)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotate)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_dotplot)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_violin)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,position_dodge)
importFrom(ggplot2,scale_color_manual)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,stat_ecdf)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_classic)
importFrom(ggplot2,xlab)
importFrom(ggplot2,ylab)
importFrom(ggpubr,ggarrange)
importFrom(ggpubr,stat_compare_means)
importFrom(ggpubr,stat_cor)
importFrom(gridExtra,grid.arrange)
importFrom(magrittr,"%>%")
importFrom(plotly,add_trace)
importFrom(plotly,ggplotly)
importFrom(plotly,layout)
importFrom(plotly,plot_ly)
importFrom(stats,ks.test)
importFrom(stats,wilcox.test)
importFrom(utils,combn)
